<?php
	
	/* 
		Plugin Name: Gnosis Person Data Collection Widget 
		Description: WordPress plugin to capture and submit visitor signup information to a Gnosis Database.
		Author: Gnosis for Nonprofits.  (Dev: Jacob Ward - http://www.jacobward.co.uk)
		Version: 1.0.1
		Author URI: http://www.gnosisfornonprofits.com
		Plugin URI: http://www.gnosisfornonprofits.com/kb/wordpress
	*/

	global $wpdb;
	
	// Adding menu items
	add_action('admin_menu', 'gnosis_menu_actions');
	
	// Functions to include admin pages
	function gnosis_settings() {  
		include('gnosis-admin.php'); 
	}	

	// Function to create menu links
	function gnosis_menu_actions() {  
		add_menu_page('Gnosis Person Data Collection Widget Config', 'Gnosis PD Config', 1, 'gnosis_settings_page', 'gnosis_settings');
	}

    // Registering activation hooks
	register_activation_hook(__FILE__, 'create_database_tables');	// Creating database tables on plugin load
	
	// Function for creating database tables
	function create_database_tables() {
		
		global $wpdb;
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		
		// Creating table for Gnosis fields
		$gnosisFieldsTable = $wpdb->prefix . 'gnosis_fields';
		
		$gnosisFieldsSqlArray = array (
			'gnosis_fields_id' => "CREATE TABLE IF NOT EXISTS `$gnosisFieldsTable` (
				`gnosis_fields_id` bigint(20) NOT NULL AUTO_INCREMENT,
				`gnosis_fields_attribute` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
				`gnosis_fields_name` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
				`gnosis_fields_datatype` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
				`gnosis_fields_display` tinyint(1) NOT NULL,
				`gnosis_fields_require` tinyint(1) NOT NULL,
				PRIMARY KEY (`gnosis_fields_id`)
				) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
			", 
		);
		
		// For each sql query in array, execute to create tables in database
		foreach ($gnosisFieldsSqlArray as $sql) {
			dbDelta($sql);
		}
		
		// Inserting required fields into database
		$gnosisRequiredFieldsSqlArray = array (
		
			'gnosis_required_fields_fname' => "INSERT INTO `$gnosisFieldsTable` (`gnosis_fields_id`, `gnosis_fields_attribute`, `gnosis_fields_name`, `gnosis_fields_datatype`, `gnosis_fields_display`, `gnosis_fields_require`) VALUES
				(1, 'PFirstName', 'First Name', 'string', 1, 1),
				(2, 'PLastName', 'Last Name', 'string', 1, 1),
				(3, 'EEmailAddress', 'Email Address', 'string', 1, 1), 				
				(4, 'PTitle', 'Title', 'string', 0, 0), 
				(5, 'PMidName', 'Middle Name', 'string', 0, 0), 
				(6, 'PSuffix', 'Suffix', 'string', 0, 0), 
				(7, 'PPrefName', 'Preferred Name', 'string', 0, 0), 
				(8, 'PMemberPassword', 'Member Password', 'string', 0, 0), 
				(9, 'PReferredBy', 'Referred By', 'string', 0, 0), 
				(10, 'PDOB_fixed', 'DOB', 'date', 0, 0), 
				(11, 'PGender', 'Gender', 'boolean', 0, 0), 
				(12, 'PType', 'Record Type', 'string', 0, 0), 
				(13, 'PStatus', 'Membership Status', 'string', 0, 0), 
				(14, 'TPhoneNumberBus', 'Business Phone', 'string', 0, 0), 
				(15, 'TPhoneNumberHome', 'Home Phone', 'string', 0, 0), 
				(16, 'TPhoneNumberMobile', 'Mobile Phone', 'string', 0, 0), 
				(17, 'TPhoneNumberOther', 'Other Phone', 'string', 0, 0), 
				(18, 'AAddress1', 'Address Line 1', 'string', 0, 0), 
				(19, 'AAddress2', 'Address Line 2', 'string', 0, 0), 
				(20, 'ACity', 'City', 'string', 0, 0), 
				(21, 'AState', 'State', 'string', 0, 0), 
				(22, 'AZip', 'Zip/Post Code', 'string', 0, 0), 
				(23, 'ACountry', 'Country', 'string', 0, 0)
			;", 
		
		);
		
		// For each sql query in array, execute to add data to table
		foreach ($gnosisRequiredFieldsSqlArray as $sql) {
			dbDelta($sql);
		}
		
		// Creating table for Gnosis settings
		$gnosisSettingsTable = $wpdb->prefix . 'gnosis_settings';	// Campaign/Stats junction table
		
		$gnosisSettingsSqlArray = array (
			'gnosis_settings_id' => "CREATE TABLE IF NOT EXISTS `$gnosisSettingsTable` (
				`gnosis_settings_id` bigint(20) NOT NULL AUTO_INCREMENT,
				`gnosis_settings_user` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
				`gnosis_settings_submit_text` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
				PRIMARY KEY (`gnosis_settings_id`)
				) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
			", 
		);
		
		// For each sql query in array, execute to create tables in database
		foreach ($gnosisSettingsSqlArray as $sql) {
			dbDelta($sql);
		}
		
		// Creating table for Custom fields
		$gnosisCustomTable = $wpdb->prefix . 'gnosis_custom';
		
		$gnosisCustomSqlArray = array (
			'gnosis_fields_id' => "CREATE TABLE IF NOT EXISTS `$gnosisCustomTable` (
				`gnosis_fields_id` bigint(20) NOT NULL AUTO_INCREMENT,
				`gnosis_fields_attribute` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
				`gnosis_fields_name` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
				`gnosis_fields_datatype` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
				`gnosis_fields_display` tinyint(1) NOT NULL,
				`gnosis_fields_require` tinyint(1) NOT NULL,
				PRIMARY KEY (`gnosis_fields_id`)
				) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
			", 
		);
		
		// For each sql query in array, execute to create tables in database
		foreach ($gnosisCustomSqlArray as $sql) {
			dbDelta($sql);
		}
	
	}

	// Adding action to call my_plugin_init on plugin initialisation
	add_action('init', 'my_plugin_init');	

	// Function to be called on plugin initialisation
	function my_plugin_init() {
		wp_register_style('prefix-style', plugins_url('css/style.css', __FILE__));
		wp_enqueue_style('prefix-style');
				
		
		wp_enqueue_style('jquery-style', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.2/themes/smoothness/jquery-ui.css');
		
	}
	
	
		
	function load_scripts() {
		wp_enqueue_script('jquery-ui-datepicker');
	}
		
		add_action('wp_enqueue_scripts', 'load_scripts');
	
	
	// Creating the widget
	class gnosis_widget extends WP_Widget {

		// constructor
		function gnosis_widget() {
			parent::WP_Widget(false, $name = __('Gnosis Widget', 'gnosis_widget'));
		}

		// widget form creation
		function form($instance) {	
			if ($instance) {
				$title = esc_attr($instance['title']);
				$textPrepend = esc_attr($instance['text_prepend']);
				$textAppend = esc_attr($instance['text_append']);
			} else {
				$title = '';
				$textPrepend = '';
				$textAppend = '';
			}
		?>
			
			<p>
				<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'gnosis_widget'); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('text_prepend'); ?>"><?php _e('Text to prepend:', 'gnosis_widget'); ?></label>
				<textarea class="widefat" id="<?php echo $this->get_field_id('text_prepend'); ?>" name="<?php echo $this->get_field_name('text_prepend'); ?>"><?php echo $textPrepend; ?></textarea>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id('text_append'); ?>"><?php _e('Text to append:', 'gnosis_widget'); ?></label>
				<textarea class="widefat" id="<?php echo $this->get_field_id('text_append'); ?>" name="<?php echo $this->get_field_name('text_append'); ?>"><?php echo $textAppend; ?></textarea>
			</p>
			
	<?php
		}

		// Widget update
		function update($new_instance, $old_instance) {
			$instance = $old_instance;
			$instance['title'] = strip_tags($new_instance['title']);
			$instance['text_prepend'] = strip_tags($new_instance['text_prepend']);
			$instance['text_append'] = strip_tags($new_instance['text_append']);
			return $instance;
		}

		// Display widget
		function widget($args, $instance) {
			extract( $args );
			// these are the widget options
			$title = apply_filters('widget_title', $instance['title']);
			$textPrepend = $instance['text_prepend'];
			$textAppend = $instance['text_append'];
			echo $before_widget;

			// Display the widget
			echo '<div class="widget-text wp_widget_plugin_box">';

			// Check if title is set
			if ($title) {
				echo $before_title . $title . $after_title;
			}

			// Check if text is set
			if($textPrepend) {
				echo '<p class="wp_widget_plugin_textarea">' . $textPrepend . '</p>';
			}

		
		
		
		
		// Layout of the widget!
		global $wpdb;
		
	
		$gnosisFieldsTable = $wpdb->prefix . 'gnosis_fields';
		$gnosisCustomTable = $wpdb->prefix . 'gnosis_custom';
		$gnosisSettingsTable = $wpdb->prefix . 'gnosis_settings';
		
			
		// Getting standard attributes fields
		$gnosisStandardAttributes = $wpdb->get_results("SELECT * FROM $gnosisFieldsTable", OBJECT_K);

		// Getting custom attributes fields
		$gnosisCustomAttributes = $wpdb->get_results("SELECT * FROM $gnosisCustomTable", OBJECT_K);
		
		// Getting user info/ID
		$gnosisUsers = $wpdb->get_results("SELECT * FROM $gnosisSettingsTable", ARRAY_N);

		
		echo '<div id="required_message"><div class="required_star">*</div> Indicates required field</div>';
		
		echo '<div id="gnosis_data_form">';
		
		echo '<form id="gnosis_submit" name="gnosis_submit" action="' . plugins_url("gnosis-submit.php", __FILE__) . '" method="POST">';
		
		// For eaqch of the standard fields set to display, echo them out
		foreach ($gnosisStandardAttributes as $gnosisStandardAttribute) {
		
			if ($gnosisStandardAttribute->gnosis_fields_display == 1) {
				
				if ($gnosisStandardAttribute->gnosis_fields_require == 1) {
					
					echo '<div class="required_star">*</div> ';
					
					echo '<div class="gnosis_label gnosis_required"><label for="' . $gnosisStandardAttribute->gnosis_fields_attribute . '">' . $gnosisStandardAttribute->gnosis_fields_name . ': </label></div>';
					
					if ($gnosisStandardAttribute->gnosis_fields_attribute == 'PDOB_fixed') {
						echo '<div class="gnosis_input gnosis_require"><input type="text" name="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" value="" onClick="this.select();" id="PDOB_fixed" /></div> <div class="clear_div"></div>';
					} elseif ($gnosisStandardAttribute->gnosis_fields_attribute == 'PGender') {
						echo '<div class="gnosis_input gnosis_require"><input type="radio" name="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" value="M" id="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" /> Male &nbsp;&nbsp;&nbsp; <input type="radio" name="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" value="F" id="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" /> Female</div> <div class="clear_div"></div>';
					} else {
						echo '<div class="gnosis_input gnosis_require"><input type="text" name="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" id="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" /></div> <div class="clear_div"></div>';
					}
						
				} else {
									
					echo '<div class="gnosis_label gnosis_optional"><label for="' . $gnosisStandardAttribute->gnosis_fields_attribute . '">' . $gnosisStandardAttribute->gnosis_fields_name . ': </label></div>';
					
					if ($gnosisStandardAttribute->gnosis_fields_attribute == 'PDOB_fixed') {
						echo '<div class="gnosis_input gnosis_optional"><input type="text" name="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" value="" onClick="this.select();" id="PDOB_fixed" /></div> <div class="clear_div"></div>';
					} elseif ($gnosisStandardAttribute->gnosis_fields_attribute == 'PGender') {
						echo '<div class="gnosis_input gnosis_optional"><input type="radio" name="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" value="F" id="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" /> Female</div> <div class="gnosis_input"><input type="radio" name="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" value="M" id="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" /> Male</div> <div class="clear_div"></div>';
					} else {
						echo '<div class="gnosis_input gnosis_optional"><input type="text" name="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" id="' . $gnosisStandardAttribute->gnosis_fields_attribute . '" /></div> <div class="clear_div"></div>';
					}
					
				}
				
			}
		
		}
		
		
		// For eaqch of the custom fields set to display, echo them out
		
		foreach ($gnosisCustomAttributes as $gnosisCustomAttribute) {
			
			if ($gnosisCustomAttribute->gnosis_fields_display == 1 && $gnosisCustomAttribute->gnosis_fields_require == 1 && $gnosisCustomAttribute->gnosis_fields_datatype == 'boolean') {
				
				$requiredBoolean = true;
			}		
		}
		
		
		if ($requiredBoolean == true) {
							
			echo '<fieldset id="boolean_fieldset"><legend><div class="required_star">* </div>Please select at least one option</legend>
					<input type="hidden" name="boolean_required" value="true" />';		
		}
		
		
		foreach ($gnosisCustomAttributes as $gnosisCustomAttribute) {
			
			if ($gnosisCustomAttribute->gnosis_fields_display == 1 && $gnosisCustomAttribute->gnosis_fields_require == 1 && $gnosisCustomAttribute->gnosis_fields_datatype == 'boolean') {
				echo '<div class="gnosis_label"><label for="' . $gnosisCustomAttribute->gnosis_fields_attribute . '">' . $gnosisCustomAttribute->gnosis_fields_name . ': </label></div><div class="gnosis_input gnosis_require"><input type="checkbox" name="Attribute:' . $gnosisCustomAttribute->gnosis_fields_attribute . '" value="true" /></div> <div class="clear_div"></div>';
			} 
		}
		
		foreach ($gnosisCustomAttributes as $gnosisCustomAttribute) {
			
			if ($gnosisCustomAttribute->gnosis_fields_display == 1 && $gnosisCustomAttribute->gnosis_fields_datatype == 'boolean') {
				
				$closeFieldset = true;
			}
		}

		
		if ($closeFieldset == true){
			echo '</fieldset>';
		}
		
		
		
		
		
		
		foreach ($gnosisCustomAttributes as $gnosisCustomAttribute) {
		
			if ($gnosisCustomAttribute->gnosis_fields_display == 1) {
			
				if ($gnosisCustomAttribute->gnosis_fields_require == 1) {
										
					if ($gnosisCustomAttribute->gnosis_fields_datatype == 'string') {
						echo '<div class="required_star">*</div> <div class="gnosis_label"><label for="' . $gnosisCustomAttribute->gnosis_fields_attribute . '">' . $gnosisCustomAttribute->gnosis_fields_name . ': </label></div>';
						echo '<div class="gnosis_input gnosis_require"><input type="text" name="Attribute:' . $gnosisCustomAttribute->gnosis_fields_attribute . '" id="' . $gnosisCustomAttribute->gnosis_fields_attribute . '" /></div> <div class="clear_div"></div>';
					} elseif ($gnosisCustomAttribute->gnosis_fields_datatype == 'date') {
						echo '<div class="required_star">*</div> <div class="gnosis_label"><label for="' . $gnosisCustomAttribute->gnosis_fields_attribute . '">' . $gnosisCustomAttribute->gnosis_fields_name . ': </label></div>';
						echo '<div class="gnosis_input gnosis_require"><input type="text" name="Attribute:' . $gnosisCustomAttribute->gnosis_fields_attribute . '" value="" onClick="this.select();" id="' . $gnosisCustomAttribute->gnosis_fields_attribute . '" /></div> <div class="clear_div"></div>';
						echo '
							<script>
							jQuery(document).ready(function() {
								jQuery("#' . $gnosisCustomAttribute->gnosis_fields_attribute . '").datepicker({
									dateFormat: "yy-mm-dd"
								});
	
							});
							</script>
						';					}
						
				} else {
					
					if ($gnosisCustomAttribute->gnosis_fields_datatype == 'string') {

						echo '<div class="gnosis_label gnosis_optional"><label for="' . $gnosisCustomAttribute->gnosis_fields_attribute . '">' . $gnosisCustomAttribute->gnosis_fields_name . ': </label></div><div class="gnosis_input gnosis_optional"><input type="text" name="Attribute:' . $gnosisCustomAttribute->gnosis_fields_attribute . '" id="' . $gnosisCustomAttribute->gnosis_fields_attribute . '" /></div> <div class="clear_div"></div>';
					} elseif ($gnosisCustomAttribute->gnosis_fields_datatype == 'boolean') {
						echo '<div class="gnosis_label gnosis_optional"><label for="' . $gnosisCustomAttribute->gnosis_fields_attribute . '">' . $gnosisCustomAttribute->gnosis_fields_name . ': </label></div><div class="gnosis_input gnosis_optional"><input type="checkbox" name="Attribute:' . $gnosisCustomAttribute->gnosis_fields_attribute . '" value="true" /></div> <div class="clear_div"></div>';					
					} elseif ($gnosisCustomAttribute->gnosis_fields_datatype == 'date') {
						echo '<div class="gnosis_label gnosis_optional"><label for="' . $gnosisCustomAttribute->gnosis_fields_attribute . '">' . $gnosisCustomAttribute->gnosis_fields_name . ': </label></div><div class="gnosis_input gnosis_optional"><input type="text" name="Attribute:' . $gnosisCustomAttribute->gnosis_fields_attribute . '" value="" onClick="this.select();" id="' . $gnosisCustomAttribute->gnosis_fields_attribute . '" /></div> <div class="clear_div"></div>';
						echo '
							<script>
							jQuery(document).ready(function() {
								jQuery("#' . $gnosisCustomAttribute->gnosis_fields_attribute . '").datepicker({
									dateFormat: "yy-mm-dd"
								});
	
							});
							</script>
						';
					}
					
				}
				
				
			
			}
		
		
		}
				
		echo '<input type="hidden" name="user_id" value="' . $gnosisUsers[0][1] . '" />';
		
		echo '<div id="gnosis_status"></div>';
		
		echo '<div id="gnosis_buttons">';
		echo '<input type="reset" name="gnosis_form_clear" value="Clear" /> ';
		echo '<input type="submit" name="gnosis_form_submit" id="gnosis_form_submit" value="' . $gnosisUsers[0][2] . '" />';
		echo '</div>';
		echo '</form>';
		
		echo '</div>';
	

?>
<?php
	
	echo '<script> var submitUrl = "' . plugins_url("gnosis-submit.php", __FILE__) . '";</script>';
	
?>

<script>
// Submitting AJAX request
jQuery(document).ready(function() {
	jQuery('#gnosis_form_submit').click(function(e) {
		e.preventDefault();
		jQuery('#gnosis_status').hide().slideDown(100).fadeIn(800);
		jQuery('#gnosis_status').html('Saving...');
		jQuery.ajax({
			url: submitUrl,
				type: 'POST',
				data: jQuery('#gnosis_submit').serialize(),
				success: function(data, textStatus, jqXHR) {
        			var json = JSON.parse(data);
        			jQuery('#gnosis_status').html(json.ResponseText).fadeIn(500);
					jQuery('#gnosis_status').delay(5000).slideUp(500).fadeOut(500);
        			if(json.ResponseText == 'Saved.') {
	        			jQuery('#gnosis_submit').each(function(){
							this.reset();
						});
					}
				},
				error: function (data, jqXHR, textStatus, errorThrown) {
        			var json = JSON.parse(data)._html;
        			jQuery('#gnosis_status').html(json.ResponseText).fadeIn(500);
					jQuery('#gnosis_status').delay(5000).slideUp(500).fadeOut(500);
			}
		});
	});
	
	
	jQuery('#PDOB_fixed').datepicker({
		dateFormat: 'yy-mm-dd'
	});
	
});
	
</script>
<?php
			
			
			
			// Check if textarea is set
			if ($textAppend) {
				echo '<p class="wp_widget_plugin_textarea">' . $textAppend . '</p>';
			}
			echo '</div>';
			echo $after_widget;
		}
	}

	// register widget
	add_action('widgets_init', create_function('', 'return register_widget("gnosis_widget");'));

?>